@@ -19,19 +19,26 @@
 
 from helm.models.cpu import CPU
 from helm.models.mem import Mem, Swap
+from helm.models.network import Network
 from helm.models.fs import FS
 from helm.views.bar import Bar
 from helm.views.histogram import Histogram
 from helm.views.ring import Ring
 from helm.widgets.cpus import CPUs
+from helm.widgets.networks import Networks
 
-from helm.helm import run
+from helm.core import run
 
 
 if __name__ == '__main__':
     run(60,
         Ring(CPU()),
-        CPUs(Histogram),
+        CPUs(Histogram, view_args={'dynamic_scale': False}),
+        Networks(Histogram,
+                 view_args={'scale': (1./(2**21)*(60 * 2**10),
+                                      1./(2**21)*(250 * 2**10),
+                                      1./(2**21)*(500 * 2**10),
+                                      1./(2**21)*(1 * 2**20))}),
         Bar(Mem()),
         Bar(Swap()),
         Bar(FS('/')))
