@@ -17,16 +17,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from ..color import BLACK, WHITE
-from ..primitives import draw_line, draw_ring, draw_text, NORTHEAST
-from .. import view
+from helm.color import BLACK
+from helm.primitives import draw_line, draw_text, NORTHEAST
+from helm import view
 
 
 class Bar(view.View):
-    def __init__(self, model):
-        view.View.__init__(self)
-        self.model = model
-
     def init(self, width, height=None):
         view.View.init(self, width, 20)
 
